Struct sequoia_ipc::Context
source · pub struct Context { /* private fields */ }Expand description
A Context for Sequoia.
Examples
A context with reasonable defaults can be created using
Context::new:
let c = Context::new()?;A context can be configured using the builder pattern with
Context::configure:
let c = Context::configure()
.ipc_policy(IPCPolicy::Robust)
.build()?;Implementations
sourceimpl Context
impl Context
sourcepub fn configure() -> Config
pub fn configure() -> Config
Creates a Context that can be configured.
The configuration is seeded like in Context::new, but can be
modified. A configuration has to be finalized using
.build() in order to turn it into a Context.
sourcepub fn ipc_policy(&self) -> &IPCPolicy
pub fn ipc_policy(&self) -> &IPCPolicy
Returns the IPC policy.