pub struct Server { /* private fields */ }
Creates a new server for the descriptor.
Creates a Context from env::args().
Turns this process into a server.
External servers must call this early on.
On Linux expects ‘stdin’ to be a listening TCP socket.
On Windows this expects SOCKET env var to be set to a listening socket
of the Windows Sockets API SOCKET value.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.